<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              firehawkcrm.com
 * @since             1.0.0
 * @package           Fcrm_Service
 *
 * @wordpress-plugin
 * Plugin Name:       Firehawk Services
 * Plugin URI:        https://firehawk.digital/services
 * Description:       Display services from Firehawk CRM on your website
 * Version:           1.1.5
 * Author:            Grant Bevan
 * Author URI:        firehawk.digital
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       fcrm-service
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '1.1.5' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-fcrm-service-activator.php
 */
function activate_fcrm_service() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-fcrm-service-activator.php';
	Fcrm_Service_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-fcrm-service-deactivator.php
 */
function deactivate_fcrm_service() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-fcrm-service-deactivator.php';
	Fcrm_Service_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_fcrm_service' );
register_deactivation_hook( __FILE__, 'deactivate_fcrm_service' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-fcrm-service.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_fcrm_service() {

	$plugin = new Fcrm_Service();
	$plugin->run();

}
run_fcrm_service();
