<?php
/**
 * This file contains all publicly accessible API functions used in and for BTF.
 * All of them are pluggable and can be replaced with your own.
 */

$api_key = get_option('fcrm_service_api_key');


class Fcrm_Service_Api
{
    public static function get_clients($params)
    {
        if (isset($params["from-today"])) {
          $params["fromToday"] = $params["from-today"] === "true";
        }

        $range = [];
        $hasRange = false;
        if (isset($params["range-months"]) && $params["range-months"] > 0) {
          $range["months"] = $params["range-months"];
          $hasRange = true;
        }

        if (isset($params["range-days"]) && $params["range-days"] > 0) {
          $range["days"] = $params["range-days"];
          $hasRange = true;
        }
        if (isset($params["range-hours"]) && $params["range-hours"] > 0) {
          $range["hours"] = $params["range-hours"];
          $hasRange = true;
        }

        if ($hasRange) {
          $params["range"] = $range;
        }

        $fcrmTeam = get_option('fcrm_service_team');
        $request_params = array('body' => $params);

        $url = "https://us-central1-fcrm-e17b0.cloudfunctions.net/funeralServices/api/clients/" . $fcrmTeam;
        $request = wp_remote_post($url, $request_params);
        if (is_wp_error($request)) {
            return null;
        }
        $body = wp_remote_retrieve_body($request);
        $data = json_decode($body);

        if (! empty($data)) {
          return $data;
        } else {
          return null;
        }
    }

    public static function get_client($id)
    {
        $fcrmTeam = get_option('fcrm_service_team');

        $url = "https://us-central1-fcrm-e17b0.cloudfunctions.net/funeralServices/api/client/" . $id . "?teamId=".$fcrmTeam;
        $request = wp_remote_get($url);
        if (is_wp_error($request)) {
            return null;
        }
        $body = wp_remote_retrieve_body($request);
        $data = json_decode($body);

        if (! empty($data)) {

          $data->meta_dod = Fcrm_Service_Api::format_dod($data);
          $data->meta_service = Fcrm_Service_Api::format_service_details($data);

          return $data;
        } else {
          return null;
        }
    }

    public static function format_service_details($client) {
      $details = "Service Details: ";

      if (isset($client->serviceDateTime)) {
          $serviceTime = new DateTime($client->serviceDateTime);
          $details .= $serviceTime->format('D j F g:i a').' ';
      }

      if (isset($client->serviceVenue)) {
        $venueName = '';
        $hasVenue = false;

        if (isset($client->serviceVenue->name)) {
          $hasVenue = true;
          $venueName .= $client->serviceVenue->name;
        }
        if (isset($client->serviceVenue->address)) {
          if ($hasVenue) {
            $venueName .= ', ';
          }
          $hasVenue = true;
          $venueName .= $client->serviceVenue->address;
        }

        if ($hasVenue) {
          $details .= 'at '. $venueName;
        }
      }

      return $details;
    }

    public static function format_dod($client) {
      if (isset($client->clientDateOfBirth) && isset($client->clientDateOfDeath)) {
          $date1 = new DateTime($client->clientDateOfBirth);
          $date2 = new DateTime($client->clientDateOfDeath);
          return $date1->format('Y') . " - " . $date2->format('Y');
      } elseif (isset($client->clientDateOfDeath)) {
          $date1 = new DateTime($client->clientDateOfDeath);
          return $date1->format('Y');
      }
    }
}
